---
title: Quick test
output:
  ioslides_presentation:
    widescreen: true
    smaller: true
editor_options:
  chunk_output_type: console
kernelspec:
  display_name: Python 3
  language: python
  name: python3
jupytext:
  root_level_metadata_filter: -title,-output,-editor_options
---

```{code-cell} ipython3
1+2+3
```

```{code-cell} ipython3

```
